
import * as Graph from '../../components/Graph';
import { H4 } from '../../components/Headings';
import { Collapsible } from "../../components/Collapsible";
import PreCyse from '../../components/precyse';

export function HPFeedback(){

    return(
        <div>
            <H4 text="Our surveys on cystic fibrosis and gene therapy"></H4>
            <p> We are proud of our surveys on gene therapy and cystic fibrosis (CF), which explore knowledge about the disease and willingness to embrace gene therapy as a potential treatment. Since we wanted to differentiate between the general public and affected CF patients, we created two different surveys.</p>
            <div className="row align-items-center">
                <div className='row graphs' >
                <div className="col">
                    <Graph.HowOftenTreatmentatients/>
                </div>
                <div className="col">
                    <Graph.OpenToGeneTherapyatients/>
                </div>
                <div className="col">
                    <Graph.MoreInfoOnTherapyBoth/>
                </div>
                </div>
                <div className="row ">
                <div className="col">
                    <p>The majority of respondents (62.70%) indicated that they or their relative require medical treatment or therapy daily. Weekly treatment was necessary for 14.59%, while 9.73% needed therapy several times per week. Only 6.49% reported needing treatment either monthly or rarely. The high frequency of daily treatments highlights the heavy burden of managing cystic fibrosis and reinforces the potential appeal of gene therapy, which could reduce the need for constant medical intervention. </p>
                </div>
                <div className="col">    
                    <p>A significant majority, 78.72%, indicated that they would be open to gene therapy if it significantly improved symptoms, while only 1.42% said no. This overwhelming support aligns with the hope patients have for less invasive and more effective treatments. This also reflects the possibility of gene therapy becoming a central treatment method, especially given the heavy therapeutic load CF patients already carry.</p>
                </div>
                <div className="col"> 
                    <p>A vast majority, 93.48%, expressed interest in more information about gene therapy. This mirrors the general public’s desire for further education and suggests that while there is strong support for gene therapy, people still feel they lack sufficient knowledge to make fully informed decisions. Patients especially emphasized the importance of safety and long-term efficacy, areas that should be focal points in future communications. </p>
                </div>
            </div>
            </div>
            
            <div>
                <H4 text="Concluding thoughts "></H4>
                <p>The surveys with both the general public and CF patients show promising openness towards gene therapy, though concerns about safety and long-term effects remain. Emotional stress was highlighted as a greater burden than physical symptoms, reinforcing the appeal of gene therapy to reduce both physical and emotional challenges. Most patients require daily or frequent therapies like medication, physiotherapy, and inhalation, making a less frequent or even one-time gene therapy, as proposed in our research, highly attractive. Participants added comments such as <strong>“The dream of healing still exists!”</strong>, encouraging us in our research.</p>
                <p>Both groups are ready for gene therapy, with patients showing fewer "no concerns," likely due to their familiarity with risks and off-target effects. This underscores the importance of our focus on safety and precision to minimize risks. Our research is designed to address these concerns through targeted approaches – <strong>we are <PreCyse/>!</strong></p>
                <p>Additionally, there’s a clear demand for more information, especially via platforms like TV, social media, and the internet. Targeted educational campaigns through these channels will be crucial to increase awareness and understanding, helping to build on the existing optimism and foster greater acceptance of gene therapy, like we do in our various public outreach efforts for science communication.</p>
            </div>
            <div>
                <Collapsible id="collapsible1" open={false} title="See the full results of our surveys">
                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.WhoAffectedatients/>
                            </div>
                            <div className='col-4'>
                            <Graph.HowDidYouLearnPublic/>
                            </div>
                            <div className='col'>
                            <Graph.HeardOfCFPublic/>
                            </div>
                        </div>
                        <div className='row'>
                        <div className="col">
                                <p>56.76% of respondents reported that they are related to someone with CF, while 43.24% stated they are affected by CF themselves. This likely reflects the fact that many parents completed the survey on behalf of their children, as CF is typically diagnosed at a young age. The high involvement of parents underscores how the disease impacts not just the patients themselves but also their families, who are deeply involved in the day-to-day management of CF. This highlights the importance of considering both the perspectives of young patients and their families when discussing gene therapy and CF treatments, as parents often play a critical role in decision-making regarding new treatment options.</p>
                            </div>
                            <div className="col"> 
                                <p>82.89% of respondents have heard of cystic fibrosis, while 17.11% had not. The high level of awareness about CF suggests that the general public is relatively informed about the condition, possibly due to the visibility of the disease through media, health campaigns, or personal connections to affected individuals. However, the 17% unfamiliar with CF indicates that further outreach is necessary, particularly focusing on this demographic to spread knowledge about the disease and potential treatments, including gene therapy. </p>
                            </div>
                            <div className="col">
                                <p>The majority of respondents (44.17%) learned about CF through media channels, such as television, news, or the internet. Other significant sources of information include family and friends (25.15%), as well as educational institutions (20.86%). Interestingly, only 3.68% of respondents learned about CF from healthcare providers, suggesting that the disease is more commonly understood through external sources rather than direct medical education. This reliance on media and personal connections highlights the importance of accurate and accessible information in the public domain, especially when considering the introduction of gene therapy as a treatment option. </p>
                            </div>
                        </div>
                    </div>
 
                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.AgeDiagnosisatients/>
                            </div>
                            <div className='col'>
                            <Graph.HowMuchDoesItAffectYouatients/>
                            </div>
                            <div className='col'>
                            <Graph.WhichSymptomsatients/>
                            </div>
                        </div>
                        <div className='row'>
                            <div className="col">
                                
                                <p>26.23% of respondents indicated that CF was diagnosed either through newborn screening or between the ages of 1 and 10. Another 21.86% reported diagnosis a few months after birth, and 18.03% were diagnosed about one week after birth. This highlights the early detection of CF, often requiring lifelong management, which can be emotionally challenging for families. Early diagnosis increases the appeal of treatments like gene therapy, which could offer long-term benefits with fewer interventions.</p>
                                </div>
                                <div className="col">
                                    
                                    <p>42.16% of respondents rated the impact of cystic fibrosis on daily life as a 3 out of 5, indicating a moderate effect. Additionally, 32.97% rated the impact as a 2, while 12.43% rated it as a 4. Only 4.32% of respondents felt that CF had a very strong impact (rating it a 5), and 8.11% rated it a 1, suggesting little to no daily effect. These results indicate that for many patients and families, CF has a notable but varied impact on daily life, reinforcing the importance of treatments like gene therapy that could alleviate the burden. </p>
                                </div>
                                <div className="col">
                                    
                                    <p>This chart shows that 23.19% of respondents identified abdominal pain as the most frequent symptom, followed by chronic cough (18.95%) and frequent lung infections (13.72%). Interestingly, symptoms like muscle weakness (2%) and delayed growth (6.23%) were less commonly reported. The emphasis on chronic respiratory and gastrointestinal symptoms aligns with CF being a metabolic disease affecting the whole body like experts such as Dr. Olariu explained to us, reinforcing the need for comprehensive treatments like gene therapy that target multiple aspects of the disease at the cellular level.</p>
                             </div>
                        </div>
                    </div>
                   

                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.WhichTherapyDoYouUseatients/>
                            </div>
                            <div className='col'>
                            <Graph.MostStressfulForRelativeatients/>
                            </div>
                        </div>
                        <div className='row'>
                            <div className="col">
                                
                                <p>The most common therapies used by respondents included medication (29.20%), physiotherapy (26.32%), and inhalation therapy (26.63%). These treatments are prominently represented in CF care, but they also reflect a burdensome regimen that requires constant management. The frequency with which patients must undergo these treatments may increase their interest in gene therapy, which could offer a less demanding option with potentially longer-lasting results</p>
                            </div>
                            <div className="col">
                                
                                <p>The survey reveals that 36.79% of respondents identified emotional stress as the most stressful aspect of cystic fibrosis, closely followed by physical symptoms at 32.78%. Social restrictions were noted by 17.73% of respondents, and financial burden was a concern for 11.37%. Only 1.34% cited other factors. These results show that emotional and physical challenges dominate the stressors for patients and families, highlighting the need for treatments like gene therapy that could reduce both the physical and emotional burdens of managing CF. </p>
                            </div>
                        </div>
                    </div>
                    

                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.HeadrofGeneTherapyPatients/>
                            </div>
                            <div className='col'>
                            <Graph.HeadOfGeneTherapyPublic/>
                            </div>
        
                        </div>
                        <div className='row'>
                        <div className="col">
                                
                                <p>Among this group, 76.76% of respondents had heard of gene therapy, which is a higher awareness rate than seen in the general public survey. However, 23.24% remain unfamiliar with it, pointing to a need for further education. The higher familiarity here could be attributed to the fact that patients and their families are more engaged with medical advancements due to the severe nature of CF. </p>
                            </div>
                            <div className="col">
                                
                                <p>When asked about gene therapy, 67.58% of respondents indicated familiarity with the concept, while 32.42% had not heard of it. This demonstrates a moderate level of awareness, but it is clear that a third of the population remains unaware of gene therapy. This gap in knowledge represents a significant opportunity for educational efforts, as the lack of familiarity could impact the acceptance and support for gene therapy as a viable treatment option for CF. The comments suggest that many see gene therapy as an emerging field, but there is some confusion regarding its practical applications.</p>
                            </div>
                        </div>
                    </div>
                 

                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.HowWellInformedAboutCFPublic/>
                            </div>
                            <div className='col'>
                            <Graph.WhatMeasuresPublic/>
                            </div>
                        </div>
                        <div className='row'>
                        <div className="col">
                                
                                <p>In terms of knowledge about CF, 58.60% of respondents stated that they are somewhat well informed, and only 21.66% felt extremely well informed (see diagram 2). A smaller portion, 13.38%, indicated that they are not very informed, and 6.37% admitted to being not informed at all. This suggests that while CF is recognized by a large portion of the public, deeper knowledge about the disease is lacking. That is why we are doing science communication at our various public outreach events! </p>
                            </div>
                            <div className="col">
                                
                                <p>Respondents were asked what actions could be taken to improve CF awareness (see diagram 4). The most popular option, chosen by 22.87%, was publicity campaigns on TV, radio, and other mass media outlets. Information events at schools and universities followed at 13.20%, along with documentary films and short movies about life with CF (14.01%). These findings suggest that the public sees media as the most effective way to spread awareness, a strategy that could also be employed to educate about gene therapy. The public appears to favor visual and accessible formats, which could be used to highlight the benefits of new treatments like gene therapy. </p>
                            </div>
                        </div>
                    </div>
                   

                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.BasicPositionatients/>
                            </div>
                            <div className='col'>
                            <Graph.WhatCocernsAboutGeneTherapyatients/>
                            </div>
                            <div className='col'>
                            <Graph.WhatCocernsAboutGeneTherapyPublic/>
                            </div>
                        </div>
                        <div className='row'>
                        <div className="col">
                            
                            <p>The survey reveals that 35.00% of respondents had a very positive view of gene therapy, and 30.00% rated it a 4 out of 5 (see diagram 20). Only 5.71% rated it a 2 or lower. The overall positivity suggests that many patients and families are hopeful about the potential of gene therapy, perhaps because of their familiarity with the limitations of current treatments. This optimism could be leveraged to support future clinical trials or educational initiatives.</p>  
                        </div>
                        <div className="col">
                              
                            <p>Concerns about gene therapy primarily revolved around safety and side effects and long-term effects (both 59.46%) (see diagram 22). Cost and accessibility also remain important issues for 32.43% of respondents. Only 0.54% expressed no concerns, showing that while there is optimism, there are significant fears to address. These concerns were similarly expressed in the general public survey but are more pronounced among patients, likely due to their firsthand experience with long-term treatments.</p>                     
                        </div>
                        <div className="col">
                            
                            <p>The most common concern, shared by 28.77% of respondents, was related to the safety and side effects of gene therapy, followed by long-term effects (27.85%) and costs or accessibility (24.20%) (see diagram 9). Ethical questions were raised by 14.61% of participants, while only 4.57% had no concerns at all. These concerns echo comments made in other parts of the survey, where respondents expressed interest in learning more about the safety protocols and regulatory measures surrounding gene therapy. Clearly, addressing these concerns in future public engagements will be critical to fostering wider acceptance. </p>
                        </div>
                    
                        </div>
                    </div>
                   
                    <div className='row'>
                        <div className='row'>
                            <div className='col'>
                            <Graph.WhatCouldGeneTherapyMeanForMedicinePublic/>
                            </div>
                            <div className='col'>
                            <Graph.WouldYouDoGeneTherapyPublic/>
                            </div>
                            <div className='col'>
                            <Graph.WhatFormMoreInfoPublic/>
                            </div>
                        </div>
                        <div className='row'>
                        <div className="col">
                            
                            <p>Nearly half (49.59%) of respondents believe that gene therapy represents a major advance in the treatment of diseases, while 47.97% acknowledged that gene therapy offers some progress but also carries risks (see diagram 7). Less than 2% of respondents expressed concern that gene therapy could bring more risks than benefits. This overall positive outlook on gene therapy is encouraging, but it also underscores the need to address concerns about safety and long-term effects, which were often mentioned in the comments. The optimism shown here can be a strong foundation for promoting gene therapy, especially with appropriate education on mitigating risks.</p>
                        </div>
                        <div className="col">
                            
                            <p>A strong majority, 85.22% of respondents, indicated that they would consider opting for gene therapy, with only 1.74% saying they would not, and 13.04% responding with "maybe." (see diagram 8). This result demonstrates considerable openness to gene therapy among the public, though the minority expressing hesitation suggests there are lingering doubts. Comments frequently mentioned concerns over safety and long-term effects, suggesting that these issues need to be addressed to convert "maybe" responses into more confident support for gene therapy.</p>                   
                        </div>
                        <div className="col">
                           
                            <p>When asked how they would prefer to receive more information, 22.62% of respondents selected TV documentaries and programs as their preferred medium, while 16.63% expressed interest in websites and online resources (see diagram 11). This preference for visual and online formats aligns with the public’s general reliance on media for learning about CF and other medical topics. Social media and online communities (15.96%) also ranked highly, indicating that digital platforms are an effective way to reach a broad audience. These findings can guide future efforts to create engaging and informative content about CF and gene therapy.</p>
                        </div>
                        </div>
                    </div>

                </Collapsible>
            </div>
        </div>
    )
}